@@ -16,19 +16,27 @@ sub awx_wx_config_data {
     $data{libs} =~ s/\-lwx\S+//g;
     ( my $ver = $data{version} ) =~ s/\.\d+$//;
 
-    my $lib_link = sub {
+    my $lib_link  = sub {
         $_[0] eq 'core' ?
           '-l' . $data{basename} . '-' . $ver :
           '-l' . $data{basename}  . '_' . $_[0] . '-' . $ver;
     };
+    my $lib_dll = sub {
+        'lib' . substr( $lib_link->( $_[0] ), 2 ) . '.' . $self->awx_dlext;
+    };
 
-    $data{dlls} = { core => { link => $lib_link->( 'core' ) },
-                    stc  => { link => $lib_link->( 'stc' ) },
-                    xrc  => { link => $lib_link->( 'xrc' ) },
-                    gl   => { link => $self->_call_wx_config( 'gl-libs' ) },
+    $data{dlls} = { core => { dll  => $lib_dll->( 'core' ),
+                              link => $lib_link->( 'core' ) },
+                    stc  => { dll  => $lib_dll->( 'stc' ),
+                              link => $lib_link->( 'stc' ) },
+                    xrc  => { dll  => $lib_dll->( 'xrc' ),
+                              link => $lib_link->( 'xrc' ) },
+                    gl   => { dll  => $lib_dll->( 'gl' ),
+                              link => $self->_call_wx_config( 'gl-libs' ) },
                    };
+    delete $data{dlls}{gl} unless $data{dlls}{gl}{link};
 
-    $self->{data} = \%data;
+    $self->{awx_data} = \%data;
 }
 
 sub awx_uses_bakefile { 0 }
